v3

package
v1.32.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 23, 2026 License: Apache-2.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

const CONSTANT_HASH_VALUE = "contour"

nolint:revive

Variables

var Hash = ConstantHash{}

Functions

func NewRequestLoggingCallbacks added in v1.11.0

func NewRequestLoggingCallbacks(log logrus.FieldLogger) envoy_server_v3.Callbacks

NewRequestLoggingCallbacks returns an implementation of the Envoy xDS server callbacks to provide request detail logging. Currently only xDS State of the World callbacks are implemented.

func RegisterServer

func RegisterServer(srv Server, g *grpc.Server)

RegisterServer registers the given xDS protocol Server with the gRPC runtime.

Types

type ConstantHash added in v1.28.0

type ConstantHash struct{}

ConstantHash is a specialized node ID hasher used to allow any instance of Envoy to connect to Contour regardless of the service-node flag configured on Envoy.

func (ConstantHash) ID added in v1.28.0

func (ConstantHash) String added in v1.28.0

func (c ConstantHash) String() string

Jump to