Documentation
¶
Index ¶
- func ClusterDiscoveryType(t envoy_cluster_v3.Cluster_DiscoveryType) *envoy_cluster_v3.Cluster_Type
- func ConfigSource(cluster string) *envoy_core_v3.ConfigSource
- func DownstreamTLSTransportSocket(tls *envoy_tls_v3.DownstreamTlsContext) *envoy_core_v3.TransportSocket
- func Endpoints(addrs ...*envoy_core_v3.Address) []*envoy_endpoint_v3.LocalityLbEndpoints
- func LBEndpoint(addr *envoy_core_v3.Address) *envoy_endpoint_v3.LbEndpoint
- func SocketAddress(address string, port int) *envoy_core_v3.Address
- func UpstreamTLSTransportSocket(tls *envoy_tls_v3.UpstreamTlsContext) *envoy_core_v3.TransportSocket
- func WriteBootstrap(c *envoy.BootstrapConfig) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ClusterDiscoveryType ¶
func ClusterDiscoveryType(t envoy_cluster_v3.Cluster_DiscoveryType) *envoy_cluster_v3.Cluster_Type
ClusterDiscoveryType returns the type of a ClusterDiscovery as a Cluster_type.
func ConfigSource ¶
func ConfigSource(cluster string) *envoy_core_v3.ConfigSource
ConfigSource returns a *envoy_core_v3.ConfigSource for cluster.
func DownstreamTLSTransportSocket ¶
func DownstreamTLSTransportSocket(tls *envoy_tls_v3.DownstreamTlsContext) *envoy_core_v3.TransportSocket
DownstreamTLSTransportSocket returns a custom transport socket using the DownstreamTlsContext provided.
func Endpoints ¶
func Endpoints(addrs ...*envoy_core_v3.Address) []*envoy_endpoint_v3.LocalityLbEndpoints
Endpoints returns a slice of LocalityLbEndpoints. The slice contains one entry, with one LbEndpoint per *envoy_core_v3.Address supplied.
func LBEndpoint ¶
func LBEndpoint(addr *envoy_core_v3.Address) *envoy_endpoint_v3.LbEndpoint
LBEndpoint creates a new LbEndpoint.
func SocketAddress ¶
func SocketAddress(address string, port int) *envoy_core_v3.Address
SocketAddress creates a new TCP envoy_core_v3.Address.
func UpstreamTLSTransportSocket ¶
func UpstreamTLSTransportSocket(tls *envoy_tls_v3.UpstreamTlsContext) *envoy_core_v3.TransportSocket
UpstreamTLSTransportSocket returns a custom transport socket using the UpstreamTlsContext provided.
func WriteBootstrap ¶
func WriteBootstrap(c *envoy.BootstrapConfig) error
WriteBootstrap writes bootstrap configuration to files.
Types ¶
This section is empty.