Documentation
¶
Index ¶
Constants ¶
const CONSTANT_HASH_VALUE = "contour"
nolint:revive
Variables ¶
var Hash = ConstantHash{}
Functions ¶
func NewRequestLoggingCallbacks ¶ added in v1.11.0
func NewRequestLoggingCallbacks(log logrus.FieldLogger) envoy_server_v3.Callbacks
NewRequestLoggingCallbacks returns an implementation of the Envoy xDS server callbacks to provide request detail logging. Currently only xDS State of the World callbacks are implemented.
func RegisterServer ¶
RegisterServer registers the given xDS protocol Server with the gRPC runtime.
Types ¶
type ConstantHash ¶ added in v1.28.0
type ConstantHash struct{}
ConstantHash is a specialized node ID hasher used to allow any instance of Envoy to connect to Contour regardless of the service-node flag configured on Envoy.
func (ConstantHash) ID ¶ added in v1.28.0
func (c ConstantHash) ID(*envoy_config_core_v3.Node) string
func (ConstantHash) String ¶ added in v1.28.0
func (c ConstantHash) String() string
type Server ¶
type Server interface {
envoy_service_cluster_v3.ClusterDiscoveryServiceServer
envoy_service_endpoint_v3.EndpointDiscoveryServiceServer
envoy_service_listener_v3.ListenerDiscoveryServiceServer
envoy_service_route_v3.RouteDiscoveryServiceServer
envoy_service_discovery_v3.AggregatedDiscoveryServiceServer
envoy_service_secret_v3.SecretDiscoveryServiceServer
envoy_service_runtime_v3.RuntimeDiscoveryServiceServer
}
Server is a collection of handlers for streaming discovery requests.
Click to show internal directories.
Click to hide internal directories.